@@ -11,12 +11,12 @@ use crate::{resolve, seeds::NavMarker, Focusable};
 pub(crate) fn mark_new_menus<T: Component + Clone>(
     mut cmds: Commands,
     new_markers: Query<(Entity, &NavMarker<T>), Added<resolve::TreeMenu>>,
-    queries: resolve::NavQueries,
+    children: resolve::ChildQueries,
 ) {
     let mut to_insert = Vec::new();
     for (new_menu, marker) in new_markers.iter() {
         let repeat_marker = iter::repeat((marker.0.clone(),));
-        let menu_children = resolve::children_focusables(new_menu, &queries);
+        let menu_children = children.focusables_of(new_menu);
         to_insert.extend(menu_children.into_iter().zip(repeat_marker));
     }
     cmds.insert_or_spawn_batch(to_insert);
